Structs
- Android
NdkWindow Handle - raw_window_handle_ffi:
This type is ABI-stable and FFI-compatible analogue for
raw_window_handle::AndroidNdkWindowHandle. Can be converted to and from the referenced type. - AppKit
Window Handle - raw_window_handle_ffi:
This type is ABI-stable and FFI-compatible analogue for
raw_window_handle::AppKitWindowHandle. Can be converted to and from the referenced type. - DrmWindow
Handle - raw_window_handle_ffi:
This type is ABI-stable and FFI-compatible analogue for
raw_window_handle::DrmWindowHandle. Can be converted to and from the referenced type. - GbmWindow
Handle - raw_window_handle_ffi:
This type is ABI-stable and FFI-compatible analogue for
raw_window_handle::GbmWindowHandle. Can be converted to and from the referenced type. - Haiku
Window Handle - raw_window_handle_ffi:
This type is ABI-stable and FFI-compatible analogue for
raw_window_handle::HaikuWindowHandle. Can be converted to and from the referenced type. - Ohos
NdkWindow Handle - raw_window_handle_ffi:
This type is ABI-stable and FFI-compatible analogue for
raw_window_handle::OhosNdkWindowHandle. Can be converted to and from the referenced type. - Orbital
Window Handle - raw_window_handle_ffi:
This type is ABI-stable and FFI-compatible analogue for
raw_window_handle::OrbitalWindowHandle. Can be converted to and from the referenced type. - RawWindow
Handle - UiKit
Window Handle - raw_window_handle_ffi:
This type is ABI-stable and FFI-compatible analogue for
raw_window_handle::UiKitWindowHandle. Can be converted to and from the referenced type. - Wayland
Window Handle - raw_window_handle_ffi:
This type is ABI-stable and FFI-compatible analogue for
raw_window_handle::WaylandWindowHandle. Can be converted to and from the referenced type. - WebCanvas
Window Handle - raw_window_handle_ffi:
This type is ABI-stable and FFI-compatible analogue for
raw_window_handle::WebCanvasWindowHandle. Can be converted to and from the referenced type. - WebOffscreen
Canvas Window Handle - raw_window_handle_ffi:
This type is ABI-stable and FFI-compatible analogue for
raw_window_handle::WebOffscreenCanvasWindowHandle. Can be converted to and from the referenced type. - WebWindow
Handle - raw_window_handle_ffi:
This type is ABI-stable and FFI-compatible analogue for
raw_window_handle::WebWindowHandle. Can be converted to and from the referenced type. - Win32
Window Handle - raw_window_handle_ffi:
This type is ABI-stable and FFI-compatible analogue for
raw_window_handle::Win32WindowHandle. Can be converted to and from the referenced type. - WinRt
Window Handle - raw_window_handle_ffi:
This type is ABI-stable and FFI-compatible analogue for
raw_window_handle::WinRtWindowHandle. Can be converted to and from the referenced type. - XcbWindow
Handle - raw_window_handle_ffi:
This type is ABI-stable and FFI-compatible analogue for
raw_window_handle::XcbWindowHandle. Can be converted to and from the referenced type. - Xlib
Window Handle - raw_window_handle_ffi:
This type is ABI-stable and FFI-compatible analogue for
raw_window_handle::XlibWindowHandle. Can be converted to and from the referenced type.